#!/usr/bin/perl
#=======================================================================
# FileName : cmd_SetAuthUserPasswd.pl
# Summary  : Authユーザー情報変更ベースコマンド
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2014/04/16 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use JSON;
use Encode;
use MIME::Base64;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use CmdComFunc;
use ComLog;

our %messages = ();
my $ret = ComConst::STS_OK;

$ret = &main(@ARGV);

exit $ret;

#=======================================================================
# FuncName : main
# Summary  : Authユーザー情報変更メイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2014/04/16 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my $reqFile      = $_[0];
    my $resFile      = $_[1];
    my $requestData  = "";
    my %responseData = ();
    my %conf         = ();
    $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_OK;
    $responseData{ComConst::JSON_KEY_MSG} = "";

    # 初期化
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::initializeBaseCmd($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエスト読み込み
    if($rc == ComConst::STS_OK){
        $requestData = CmdComFunc::readRequestFile($reqFile);
        ComLog::log_output(ComLog::LOG_DEBUG, Dumper($requestData));
    }

    # 機能制限チェック
    if($rc == ComConst::STS_OK){
        if(CmdComFunc::existWebFuncLimitFile() != ComConst::STS_OK){
            $rc = ComConst::STS_NG;
            $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
            $responseData{ComConst::JSON_KEY_MSG} = $messages{CM000E002} . "<br>" . $messages{CM000E003};
        }
    }

    # リクエストデータ復号化
    if($rc == ComConst::STS_OK){
        $rc = DecodeRequestData($requestData->[0]);
        ComLog::log_output(ComLog::LOG_DEBUG, Dumper($requestData));
    }

    # 入力チェック
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::checkReqData($requestData, \%responseData);
        if($rc == ComConst::STS_OK){
            my $count;
            # パスワード確認
            my $chkObj = [{
                userPasswdEqual => $requestData->[0]->{userPasswd} . " = " . $requestData->[0]->{userPasswdConf}
            }];
            $rc = CmdComFunc::checkReqData($chkObj, \%responseData);
        }
        # ユーザー名チェック
        if($rc == ComConst::STS_OK){
            $rc = IsAvailableUserName($requestData->[0]->{userName});
            if($rc != ComConst::STS_OK){
                $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
                $responseData{ComConst::JSON_KEY_MSG} = sprintf($messages{CM001E002}, $requestData->[0]->{userName});
            }
        }
        if($rc != ComConst::STS_OK){
            ComLog::log_output(ComLog::LOG_ERROR, $responseData{ComConst::JSON_KEY_MSG});
            ComLog::log_output(ComLog::LOG_ERROR, $messages{CM000E001});
        }
    }

    # レスポンスファイル出力
    CmdComFunc::writeResponseFile($resFile, \%responseData);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}

#=======================================================================
# FuncName : IsAvailableUserName
# Summary  : 利用可能ユーザー名チェック
# Argument : (IN)  $userName  : Basicユーザー名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/03/23 Kiyoshi Oishi      Initial Release
#=======================================================================
sub IsAvailableUserName {
    my $res = ComConst::STS_OK;
    my $userName = $_[0];
    my $fbnUsrs;

    $fbnUsrs = ComFunc::readJsonFile(ComConst::FORBIDDEN_BASIC_USERS);

    if(grep {$_ eq $userName} @{$fbnUsrs->{ForbiddenUserNames}}){
        $res = ComConst::STS_NG;
    }
    return $res;
}

#=======================================================================
# FuncName : DecodeRequestData
# Summary  : リクエストデータ復号化
# Argument : (IN/OUT)  $requestData  : リクエストデータ(ref)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/04/08 Kiyoshi Oishi      Initial Release
#=======================================================================
sub DecodeRequestData {
    my $res = ComConst::STS_OK;
    my $requestData = $_[0];
    my @decKeys = keys(%$requestData);
    my $tmpDecString = "";

    foreach my $decKey (@decKeys){
        # Base64で符号化されたデータを復号する
        $tmpDecString = decode_base64($requestData->{$decKey});
        # 元データに余分なデータを付加しているのでそれを除去して戻す
        $requestData->{$decKey} = (split(/ /, $tmpDecString))[0]
    }

    return $res;
}
