#!/usr/bin/perl
#=======================================================================
# FileName : cmd_UpdateSystem.pl
# Summary  : システムアップデートベースコマンド
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2014/04/16 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use JSON;
use Encode;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use CmdComFunc;
use ComLog;

our %messages = ();
my $ret = ComConst::STS_OK;

$ret = &main(@ARGV);

exit $ret;

#=======================================================================
# FuncName : main
# Summary  : システムアップデートメイン処理
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2014/04/16 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my $reqFile      = $_[0];
    my $resFile      = $_[1];
    my $requestData  = "";
    my %responseData = ();
    my %conf         = ();
    $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_OK;
    $responseData{ComConst::JSON_KEY_MSG} = "";

    # 初期化
    if($rc == ComConst::STS_OK){
        $rc = CmdComFunc::initializeBaseCmd($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエスト読み込み
    if($rc == ComConst::STS_OK){
        # nothing
    }

    # 機能制限チェック
    if($rc == ComConst::STS_OK){
        if(CmdComFunc::existWebFuncLimitFile() != ComConst::STS_OK){
            $rc = ComConst::STS_NG;
            $responseData{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
            $responseData{ComConst::JSON_KEY_MSG} = $messages{CM000E002} . "<br>" . $messages{CM000E003};
        }
    }

    # レスポンスファイル出力
    CmdComFunc::writeResponseFile($resFile, \%responseData);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}
